@@ -3,4 +3,6 @@ optimizer = dict(type='Adam', lr=1e-4)
 optimizer_config = dict(grad_clip=None)
 # learning policy
 lr_config = dict(policy='step', step=[200, 400])
-total_epochs = 600
+# running settings
+runner = dict(type='EpochBasedRunner', max_epochs=600)
+checkpoint_config = dict(interval=100)
