@@ -3,7 +3,8 @@ from .box_utils import sort_vertex, sort_vertex8
 from .custom_format_bundle import CustomFormatBundle
 from .dbnet_transforms import EastRandomCrop, ImgAug
 from .kie_transforms import KIEFormatBundle, ResizeNoImg
-from .loading import LoadImageFromNdarray, LoadTextAnnotations
+from .loading import (LoadImageFromLMDB, LoadImageFromNdarray,
+                      LoadTextAnnotations)
 from .ner_transforms import NerTransform, ToTensorNER
 from .ocr_seg_targets import OCRSegTargets
 from .ocr_transforms import (FancyPCA, NormalizeOCR, OnlineCropOCR,
@@ -29,5 +30,5 @@ __all__ = [
     'sort_vertex', 'LoadImageFromNdarray', 'sort_vertex8', 'FCENetTargets',
     'RandomScaling', 'RandomCropFlip', 'NerTransform', 'ToTensorNER',
     'ResizeNoImg', 'PyramidRescale', 'OneOfWrapper', 'RandomWrapper',
-    'TorchVisionWrapper'
+    'TorchVisionWrapper', 'LoadImageFromLMDB'
 ]
