@@ -2,7 +2,7 @@
 import numpy as np
 from mmcv.parallel import DataContainer as DC
 from mmdet.datasets.builder import PIPELINES
-from mmdet.datasets.pipelines.formating import DefaultFormatBundle
+from mmdet.datasets.pipelines.formatting import DefaultFormatBundle
 
 from mmocr.core.visualize import overlay_mask_img, show_feature
 
